Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Auth ¶
type Auth struct {
// contains filtered or unexported fields
}
Auth represents the struct used to handle authentication related operations.
func NewAuth ¶
func NewAuth(api API, docker Docker, credentials Credentials, console Console) *Auth
NewAuth creates and returns a new Auth struct instance.
Click to show internal directories.
Click to hide internal directories.