Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrFileNotFound = errors.New("config file not found")
ErrFileNotFound is the expected error if config file is not found.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Model Model `yaml:"model"`
}
Config represents the application configuration
func NewConfig ¶
NewConfig loads the configuration from a YAML file.
fs is the filesystem interface, allowing for different storage backends. filePath is the config file's path.
If the config file is not found, it returns ErrFileNotFound. Otherwise it returns a Config pointer or an error if loading fails.
type Dependencies ¶
Click to show internal directories.
Click to hide internal directories.